@@ -1,10 +1,10 @@
 package Bundle::Slash;
 
 #
-# $Id: Slash.pm,v 1.39 2005/03/29 19:02:04 pudge Exp $
+# $Id: Slash.pm,v 1.43 2006/08/18 17:44:41 pudge Exp $
 #
 
-$Bundle::Slash::VERSION = '2.51';
+$Bundle::Slash::VERSION = '2.52';
 
 1;
 
@@ -39,6 +39,8 @@ MIME::Base64            - why after URI if URI needs it?
 
 Bundle::LWP		- URI,HTML::Parser,MIME::Base64
 
+MIME::Types		- for Blob plugin
+
 HTML::Element           - For doing HTML-to-text
 
 Font::AFM               - ditto
@@ -117,6 +119,7 @@ Set::IntSpan		- HTML validator
 
 Text::Iconv		- HTML validator
 
+Data::JavaScript::Anon	- perl2js data structures
 
 =head1 DESCRIPTION
 
@@ -127,6 +130,6 @@ Our optional modules, which are not required for a default install
 and thus not installed by default, but which may become required as
 you edit your site configuration, are: Cache::Memcached Silly::Werder
 GD GD::Text GD::Graph Apache::SSI Apache::RegistryFilter GraphViz
-Net::IRC Proc::ProcessTable
+Net::IRC Proc::ProcessTable Net::Jabber IO::Socket::SSL
 
 =cut
